@@ -20,10 +20,8 @@
 from .structs.trade_api_struct import *
 from .structs.trade_spi_struct import *
 
-from .src import TradeApi as AztTradeApi
-from .src import TradeSpi as AztTradeSpi
-from .src import QuoteApi as AztQuoteApi
-from .src import QuoteSpi as AztQuoteSpi
+from .src import AztTradeApi, AztTradeSpi
+from .src import AztQuoteApi, AztQuoteSpi
 
 from .protobufs.EnumType_pb2 import *
 from AztVe.common.azt_errors import *
