@@ -27,7 +27,7 @@ from AztVe.structs import quote_spi_struct
 import threading
 
 
-class QuoteApiBase:
+class QuoteApiBase(common.AztApiObject):
     spi = AztQuoteSpi()
 
     def __init__(self):
@@ -118,7 +118,7 @@ class QuoteApiBase:
 
         if not error:
             if spi:
-                self.spi = spi
+                self.spi = common.DefaultSpi(spi)
             self.__handle.start()
 
         return error
