@@ -16,17 +16,21 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #  =============================================================================
-class QuoteSpi:
-    api = None
+class AztQuoteSpi:
+    api = None  # AztQuoteApi实例引用
 
+    # 订阅行情回报，msg为QuoteRegisterMsgs实例
     def onSubscribe(self, msg):
         pass
 
-    def onUnSubscribe(self,msg):
-        pass
-
-    def onDisconnected(self, msg):
+    # 取消订阅行情回报，msg为QuoteRegisterMsgs实例
+    def onUnSubscribe(self, msg):
         pass
 
+    # 深度行情回报，msg为QuoteStockMsg实例，error为可rasie的Exception错误或None
     def onDepthMarketData(self, msg, error):
         pass
+
+    # 连接中断回报，msg为可rasie的Exception错误或None
+    def connectionBroken(self, msg):
+        pass
