@@ -26,7 +26,7 @@ class AztTradeApi(VeApiWrapper):
     # 初始化
     def Start(self, server_addr: str, spi=None, hb_times: int = 3, hb_interval: int = 5, recv_timeout: int = None):
         if spi:
-            if spi.__class__ is type:
+            if issubclass(type(spi),type):
                 spi = spi()
             if getattr(self.spi, "api", None) is None:
                 setattr(self.spi, "api", self)
