@@ -48,7 +48,7 @@ from .trade_spi import AztTradeSpi
 logger = common.logger
 
 
-class VeApiBase:
+class VeApiBase(common.AztApiObject):
     def __init__(self):
         # 服务器地址
         self._server_addr = None
@@ -80,7 +80,7 @@ class VeApiBase:
         self._server_addr = server_addr
         # 设置spi
         if spi:
-            self.spi = spi
+            self.spi = common.DefaultSpi(spi)
 
         if hb_times is not None:
             self._heart_beat_times = hb_times
@@ -211,6 +211,7 @@ class VeApiBase:
         self.__socket.send(self.__gen_unit_msg(msg, msg_id))
 
     # report handle ----------------------------------------------------------------------------------------------------
+
     def __report_recv(self):
         while True:
             recv_msg = self.__socket.recv()
@@ -296,7 +297,6 @@ class VeApiBase:
         elif unit_msg.msg_id == Enum.KQueryHistoryOrdersAck:
             msg = MsgProto.QueryOrdersAck()
             unit_msg.msg_body.Unpack(msg)
-            # logger.debug(unit_msg, msg)
             cbmsg = trade_spi_struct.QueryOrdersAck.__proto2py__(msg)
             self.spi.onQueryHistoryOrders(cbmsg)
             self.__queue_put(Enum.KQueryHistoryOrdersAck, cbmsg)
